# Autograder JS

Esta biblioteca permite avaliar código JavaScript utilizando a API do OpenAI para fornecer feedback sem entregar a resposta completa.

## Instalação

1. Clone o repositório:
   ```bash
   git clone https://github.com/luccahiratsuca/autograder.git
   cd autograder
    ```
